# PyQQQ SDK

## How to Use the Package

You can install it by running the following command:

```
pip install pyqqq
```



## Setting Up the Development Environment

0. Create a Virtual Environment (Optional)

You can create and use a virtual environment with the following steps:

```
pyqqq-user:$ cd sdk
pyqqq-user:sdk:$ python -m venv .venv --prompt sdk
pyqqq-user:sdk:$ activate .venv/bin/activate
(sdk) pyqqq-user:sdk:$
```


1. Install Poetry

```
(sdk) pyqqq-user:sdk:$ pip install poetry
```


2. Install Dependencies

```
(sdk) pyqqq-user:sdk:$ poetry install
```

